Re: [PATCH] ARM: OMAP1: N770: Convert audio_pwr_sem in a mutex

Previous thread: [PATCH] bay: Exit if notify handler cannot be installed by Holger Macht on Monday, May 5, 2008 - 1:25 pm. (21 messages)

Next thread: [PATCH] pxafb: Convert ctrlr_sem in a mutex by Matthias Kaehlcke on Monday, May 5, 2008 - 1:50 pm. (1 message)
From: Matthias Kaehlcke
Date: Monday, May 5, 2008 - 1:31 pm

ARM: OMAP1: N770: The semaphore audio_pwr_sem is used as a
mutex. Convert it to the mutex API

Signed-off-by: Matthias Kaehlcke <matthias@kaehlcke.net>

--

diff --git a/arch/arm/mach-omap1/board-nokia770.c b/arch/arm/mach-omap1/board-nokia770.c
index bcb984f..db235ad 100644
--- a/arch/arm/mach-omap1/board-nokia770.c
+++ b/arch/arm/mach-omap1/board-nokia770.c
@@ -202,7 +202,7 @@ static struct omap_board_config_kernel nokia770_config[] __initdata = {
 #define	AMPLIFIER_CTRL_GPIO	58
 
 static struct clk *dspxor_ck;
-static DECLARE_MUTEX(audio_pwr_sem);
+static DEFINE_MUTEX(audio_pwr_lock);
 /*
  * audio_pwr_state
  * +--+-------------------------+---------------------------------------+
@@ -218,7 +218,7 @@ static DECLARE_MUTEX(audio_pwr_sem);
 static int audio_pwr_state = -1;
 
 /*
  * audio_pwr_up / down should be called under audio_pwr_sem
  */
 static void nokia770_audio_pwr_up(void)
 {
@@ -237,11 +237,11 @@ static void nokia770_audio_pwr_up(void)
 
 static void codec_delayed_power_down(struct work_struct *work)
 {
-	down(&audio_pwr_sem);
+	mutex_lock(&audio_pwr_lock);
 	if (audio_pwr_state == -1)
 		aic23_power_down();
 	clk_disable(dspxor_ck);
-	up(&audio_pwr_sem);
+	mutex_unlock(&audio_pwr_lock);
 }
 
 static DECLARE_DELAYED_WORK(codec_power_down_work, codec_delayed_power_down);
@@ -258,19 +258,19 @@ static void nokia770_audio_pwr_down(void)
 static int
 nokia770_audio_pwr_up_request(struct dsp_kfunc_device *kdev, int stage)
 {
-	down(&audio_pwr_sem);
+	mutex_lock(&audio_pwr_lock);
 	if (audio_pwr_state == -1)
 		nokia770_audio_pwr_up();
 	/* force audio_pwr_state = 0, even if it was 1. */
 	audio_pwr_state = 0;
-	up(&audio_pwr_sem);
+	mutex_unlock(&audio_pwr_lock);
 	return 0;
 }
 
 static int
 nokia770_audio_pwr_down_request(struct dsp_kfunc_device *kdev, int stage)
 {
-	down(&audio_pwr_sem);
+	mutex_lock(&audio_pwr_lock);
 	switch (stage) {
 	case 1:
 		if (audio_pwr_state == ...
@@ -218,7 +218,7 @@ static DECLARE_MUTEX(audio_pwr_sem);
 
 /*
- * audio_pwr_up / down should be called under audio_pwr_sem
+ * audio_pwr_up / down should be called under audio_pwr_lock
  */
 static void nokia770_audio_pwr_up(void)
From: Daniel Walker
Date: Monday, May 12, 2008 - 9:09 am

I submitted an identical patch to Tony in January .. I assumed it was
making it's way through the ARM tree .. I'm surprised it's not in
mainline yet ..

Tony any status on this?

Daniel

--

From: Tony Lindgren
Date: Wednesday, May 14, 2008 - 2:09 pm

Hi,


Hmm, I can't seem to find your patch and it does not show up in git-log
either in linux-omap. Maybe I never got it or never applied it?

Do you have a link for you patch in the mailing list archives so I can
look into it further?

Regards,

Tony
--

From: Daniel Walker
Date: Wednesday, May 14, 2008 - 3:41 pm

http://marc.info/?l=linux-omap&m=120063553504911&w=2

We had a discussion about it as I recall.

Daniel

--

From: Tony Lindgren
Date: Wednesday, May 14, 2008 - 4:21 pm

Thanks, I must have run git-reset --hard before I got it committed or
something. Sorry about that.

Tony
--

Previous thread: [PATCH] bay: Exit if notify handler cannot be installed by Holger Macht on Monday, May 5, 2008 - 1:25 pm. (21 messages)

Next thread: [PATCH] pxafb: Convert ctrlr_sem in a mutex by Matthias Kaehlcke on Monday, May 5, 2008 - 1:50 pm. (1 message)